@@ -15,7 +15,7 @@ import sys
 import click
 import yaml
 import os
-
+from pyngrok import conf, ngrok
 
 @click.command()
 @click.option('--verbose', '-v', is_flag=True, help="Verbose output")
@@ -79,6 +79,11 @@ def process(verbose, command, profile, env, stage, stack, app_suffix, build, api
             logger.info(exc)
         except IOError:
             logger.info("personal.env.yml not found!")
+        
+        if 'ngrok_auth_token' in personal_env_settings['environment']['personal']:
+            token = personal_env_settings['environment']['personal']['ngrok_auth_token']
+        else :
+            token=""
         aws_profile = profile if profile else personal_env_settings['environment']['personal']['profile']
         domain = personal_env_settings['environment']['personal']['domain']
         log_info(logger, aws_profile, domain, env)
@@ -207,10 +212,20 @@ def process(verbose, command, profile, env, stage, stack, app_suffix, build, api
     elif command == 'destroy':
         shell(logger, "cdk destroy " + stack + "--profile " + aws_profile, raise_error=True)
     elif command =="run":
-        ## Run build by default. Escape if false
-        if build == True :
-            logger.debug("------------ Running Dev Build --------------------")
-            shell(logger, "rm -rf client && npm run build:dev",raise_error=True)
+        logger.debug("------------ Starting Ngrok on port 9000 --------------------")
+        if token :
+            # Set the user auth token for Ngrok
+            conf.get_default().auth_token = token
+        
+        # Open a HTTP tunnel on port 9000
+        http_tunnel = ngrok.connect(9000)
+        
+        # Set the AWS_APP_DOMAIN to the Ngrok public URL which is replaced in app's atlassian-connect.json
+        os.environ["AWS_APP_DOMAIN"] = http_tunnel.public_url.replace('http://','')
+        
+        ## Always run the build since we start Ngrok here and need the url
+        logger.debug("------------ Running Dev Build --------------------")
+        shell(logger, "rm -rf client && npm run build:dev",raise_error=True)
 
         shell(logger, "npm run start", raise_error=True)
     elif command =="build:dev":
@@ -266,7 +281,7 @@ def deploy_module_services(logger,app_name,stage,app_domain,brand,env,app_suffix
         shell(logger,"cd ./node_modules/ac-module-services/lib/API/resources/automation-lambda && ./gradlew clean build --refresh-dependencies && cd - ",raise_error=True)
 
     ## Deploying ac-module-services
-    shell(logger, "cdk deploy '*' --app 'npx ts-node ./node_modules/ac-module-services/bin/ac-module-services.js " + env + " " + app_domain + "'" +
+    shell(logger, "cdk deploy '*' --app 'npx ts-node ./node_modules/ac-module-services/bin/ac-module-services.js " + env + " " + app_domain + " " + stage + "'" +
                   " --require-approval never --profile " + aws_profile, raise_error=True)
     return True
 
